@@ -174,7 +174,7 @@ CORBA_Object
 bonobo_activation_internal_activation_context_get_extended (gboolean           existing_only,
                                                             CORBA_Environment *ev)
 {
-	BonoboActivationBaseService base_service = {};
+	BonoboActivationBaseService base_service = { NULL };
 
 	base_service.name = "IDL:Bonobo/ActivationContext:1.0";
 	base_service.session_name = bonobo_activation_session_name_get ();
@@ -187,7 +187,7 @@ bonobo_activation_internal_activation_context_get_extended (gboolean           e
 CORBA_Object
 bonobo_activation_activation_context_get (void)
 {
-	BonoboActivationBaseService base_service = {};
+	BonoboActivationBaseService base_service = { NULL };
 
 	base_service.name = "IDL:Bonobo/ActivationContext:1.0";
 	base_service.session_name = bonobo_activation_session_name_get ();
@@ -201,7 +201,7 @@ bonobo_activation_object_directory_get (const char *username,
                           const char *hostname,
                           const char *domain)
 {
-        BonoboActivationBaseService base_service = {};
+        BonoboActivationBaseService base_service = { NULL };
 
         base_service.name = "IDL:Bonobo/ObjectDirectory:1.0";
         base_service.session_name = bonobo_activation_session_name_get ();
@@ -534,6 +534,52 @@ bonobo_activation_orb_init (int *argc, char **argv)
 	return bonobo_activation_orb;
 }
 
+/**
+ * bonobo_activation_debug_shutdown:
+ * @void: 
+ * 
+ *   A debugging function to shutdown the ORB and process
+ * any reference count leaks that may have occured.
+ * 
+ * Return value: FALSE if there were leaks detected, else TRUE
+ **/
+gboolean
+bonobo_activation_debug_shutdown (void)
+{
+        int retval = TRUE;
+        CORBA_Environment ev;
+
+        if (is_initialized) {
+                CORBA_exception_init (&ev);
+
+                bonobo_activation_base_service_debug_shutdown (&ev);
+                if (ev._major != CORBA_NO_EXCEPTION) {
+                        retval = FALSE;
+                }
+
+                if (bonobo_activation_context != CORBA_OBJECT_NIL) {
+                        CORBA_Object_release (
+                                (CORBA_Object) bonobo_activation_context, &ev);
+                        bonobo_activation_context = CORBA_OBJECT_NIL;
+                }
+
+                if (bonobo_activation_orb != CORBA_OBJECT_NIL) {
+                        CORBA_ORB_destroy (bonobo_activation_orb, &ev);
+                        if (ev._major != CORBA_NO_EXCEPTION) {
+                                retval = FALSE;
+                        }
+                        CORBA_Object_release (
+                                (CORBA_Object) bonobo_activation_orb, &ev);
+                        is_initialized = FALSE;
+                }
+
+                CORBA_exception_free (&ev);
+
+        }
+
+        return retval;
+}
+
 const char  bonobo_activation_version []    = VERSION;
 const guint bonobo_activation_major_version = BONOBO_ACTIVATION_MAJOR_VERSION;
 const guint bonobo_activation_minor_version = BONOBO_ACTIVATION_MINOR_VERSION;
