@@ -23,6 +23,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <stdio.h>
 #include <time.h>
 #include <string.h>
@@ -194,7 +198,7 @@ ac_CORBA_Context_get_value (CORBA_Context         ctx,
 {
         return activation_server_CORBA_Context_get_value (
                 ctx, propname,
-                ex_Bonobo_ActivationContext_IncompleteContext, ev);
+                ex_Bonobo_Activation_IncompleteContext, ev);
 }
 
 
@@ -312,7 +316,7 @@ ac_query_run (impl_POA_Bonobo_ActivationContext * servant,
 	Bonobo_ServerInfo **orig_items;
 	int item_count, orig_item_count;
 	char *errstr;
-	Bonobo_ActivationContext_ParseFailed *ex;
+	Bonobo_Activation_ParseFailed *ex;
 
 	QueryExpr *qexp_requirements;
 	QueryExpr **qexp_sort_items;
@@ -323,10 +327,10 @@ ac_query_run (impl_POA_Bonobo_ActivationContext * servant,
 		puts (errstr);
 
 		g_strstrip (errstr);
-		ex = Bonobo_ActivationContext_ParseFailed__alloc ();
+		ex = Bonobo_Activation_ParseFailed__alloc ();
 		ex->description = CORBA_string_dup (errstr);
 		CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
-				     ex_Bonobo_ActivationContext_ParseFailed,
+				     ex_Bonobo_Activation_ParseFailed,
 				     ex);
 		return;
 	}
@@ -344,11 +348,11 @@ ac_query_run (impl_POA_Bonobo_ActivationContext * servant,
 				qexp_free (qexp_sort_items[i]);
 
 			g_strstrip (errstr);
-			ex = Bonobo_ActivationContext_ParseFailed__alloc ();
+			ex = Bonobo_Activation_ParseFailed__alloc ();
 			ex->description = CORBA_string_dup (errstr);
 
 			CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
-					     ex_Bonobo_ActivationContext_ParseFailed,
+					     ex_Bonobo_Activation_ParseFailed,
 					     ex);
 			return;
 		}
@@ -446,7 +450,7 @@ impl_Bonobo_ActivationContext_add_directory (PortableServer_Servant _servant,
 		child = cur->data;
 		if (CORBA_Object_is_equivalent (dir, child->obj, ev)) {
 			CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
-					     ex_Bonobo_ActivationContext_AlreadyListed,
+					     ex_Bonobo_Activation_AlreadyListed,
 					     NULL);
 			return;
 		}
@@ -484,7 +488,7 @@ impl_Bonobo_ActivationContext_remove_directory (PortableServer_Servant _servant,
 
 	if (!cur)
 		CORBA_exception_set (ev, CORBA_USER_EXCEPTION,
-				     ex_Bonobo_ActivationContext_NotListed,
+				     ex_Bonobo_Activation_NotListed,
 				     NULL);
 }
 
@@ -811,7 +815,7 @@ impl_Bonobo_ActivationContext_query (PortableServer_Servant _servant,
 }
 
 static char *
-ac_aid_to_query_string (Bonobo_ActivationID aid)
+ac_aid_to_query_string (const CORBA_char *aid)
 {
         char *tmp_aid;
         char *requirements;
@@ -897,7 +901,7 @@ ac_context_to_string_array (CORBA_Context context, char **sort_criteria,
 
 static Bonobo_ActivationResult *
 impl_Bonobo_ActivationContext_activate_from_id (PortableServer_Servant _servant,
-                                                Bonobo_ActivationID aid,
+                                                const CORBA_char *aid,
                                                 Bonobo_ActivationFlags flags,
                                                 CORBA_Context ctx,
                                                 CORBA_Environment * ev)
@@ -951,7 +955,7 @@ impl_Bonobo_ActivationContext_activate_from_id (PortableServer_Servant _servant,
 static void
 impl_Bonobo_ActivationContext_activate_from_id_async (
         PortableServer_Servant    _servant,
-        Bonobo_ActivationID       aid,
+        const CORBA_char          *aid,
         Bonobo_ActivationFlags    flags, 
         Bonobo_ActivationCallback callback_object,
         CORBA_Context             ctx, 
